<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Export;

use Doctrine\DBAL\Connection;
use PhpOffice\PhpSpreadsheet\IOFactory;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;
use function array_unshift;

/**
 * Class Translations
 *
 * @package Inti\Moto\Console\Export
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Translations extends Command
{
    private Connection $conn;

    private array $tables = [
        'category',
        'engine_type',
        'engine',
        'fuel_system',
        'fuel_control',
        'ignition',
        'lubrication_system',
        'cooling_system',
        'gearbox',
        'transmission_type',
        'clutch',
        'exhaust_system',
        'suspension',
        'brake',
        'starter',
        'electrical',
    ];

    public function __construct(Connection $conn)
    {
        parent::__construct('export:translations');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Izvozi sve nazive za prevođenje.')
            ->addArgument('datoteka', InputArgument::REQUIRED, 'Putanja do datoteke.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $file = $input->getArgument('datoteka');

        try {
            $spreadsheet = new Spreadsheet();
            $spreadsheet->removeSheetByIndex(0);

            foreach ($this->tables as $i => $table) {
                $result = $this->conn->executeQuery('SELECT id, name_en, name FROM ' . $table);
                $data = $result->fetchAllNumeric();
                array_unshift($data, ['id', 'en', 'hr']);

                $sheet = $spreadsheet->createSheet($i);
                $sheet->setTitle($table);
                $sheet->fromArray($data);

                $highestColumn = $sheet->getHighestColumn();
                $sheet->getStyle('A1:' . $highestColumn . '1')
                    ->applyFromArray([
                        'font' => ['bold' => true],
                    ]);
            }

            $writer = IOFactory::createWriter($spreadsheet, 'Xlsx');
            $writer->save($file);

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                '============================',
                $e->getMessage(),
            ]);

            return Command::FAILURE;
        }
    }
}
