<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Import;

use Doctrine\DBAL\Connection;
use PhpOffice\PhpSpreadsheet\Cell\Cell;
use PhpOffice\PhpSpreadsheet\IOFactory;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;

/**
 * Class Translations
 *
 * @package Inti\Moto\Console\Import
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Translations extends Command
{
    private Connection $conn;

    public function __construct(Connection $conn)
    {
        parent::__construct('import:translations');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Izvozi sve nazive za prevođenje.')
            ->addArgument('datoteka', InputArgument::REQUIRED, 'Putanja do datoteke.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $file = $input->getArgument('datoteka');

        try {
            $spreadsheet = IOFactory::load($file);

            foreach ($spreadsheet->getAllSheets() as $sheet) {
                $rows = $sheet->getRowIterator(2);

                foreach ($rows as $row) {
                    $data = array_values(array_map(function (Cell $cell) {
                        return $cell->getValue();
                    }, iterator_to_array($row->getCellIterator())));

                    if (!empty($data[2])) {
                        $this->conn->update($sheet->getTitle(), [
                            'name' => $data[2],
                        ], ['id' => $data[0]]);
                    }
                }
            }

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                '============================',
                $e->getMessage(),
            ]);

            return Command::FAILURE;
        }
    }
}
