<?php
declare(strict_types=1);

namespace Inti\Moto\Console\Schema;

use Doctrine\DBAL\Connection;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Throwable;

/**
 * Class Drop
 *
 * @package Inti\Moto\Console\Schema
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-moto-cli
 */
final class Drop extends Command
{
    private Connection $conn;

    public function __construct(Connection $conn)
    {
        parent::__construct('schema:drop');
        $this->conn = $conn;
    }

    protected function configure(): void
    {
        $this->setDescription('Briše sve tablice iz baze.');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        try {
            $manager = $this->conn->getSchemaManager();

            foreach ($manager->listTables() as $table) {
                foreach ($table->getForeignKeys() as $constraint) {
                    $manager->dropForeignKey($constraint, $table);
                }
            }

            foreach ($manager->listTables() as $table) {
                $manager->dropTable($table->getName());
            }

            return Command::SUCCESS;
        } catch (Throwable $e) {
            $output->writeln([
                'Došlo je do neakve pogreške:',
                '============================',
                $e->getMessage(),
            ]);

            return Command::FAILURE;
        }
    }
}
